EXPORTS
	?Cancel@CImMobilityPolicyProvider@@QAEXJ@Z @ 1 NONAME ; void CImMobilityPolicyProvider::Cancel(long)
	?CloseLog@CImMobilityLogger@@QAEXH@Z @ 2 NONAME ; void CImMobilityLogger::CloseLog(int)
	?CreateDefaultLog@CImMobilityLogger@@QAEXABVTDesC16@@@Z @ 3 NONAME ; void CImMobilityLogger::CreateDefaultLog(class TDesC16 const &)
	?CreateL@CImMobilityPolicyProvider@@SAXXZ @ 4 NONAME ; void CImMobilityPolicyProvider::CreateL(void)
	?CreateStandardLog@CImMobilityLogger@@QAEXABVTDesC16@@AAH@Z @ 5 NONAME ; void CImMobilityLogger::CreateStandardLog(class TDesC16 const &, int &)
	?Delete@CImMobilityPolicyProvider@@SAXXZ @ 6 NONAME ; void CImMobilityPolicyProvider::Delete(void)
	?GetRef@CImMobilityPolicyProvider@@SAAAV1@XZ @ 7 NONAME ; class CImMobilityPolicyProvider & CImMobilityPolicyProvider::GetRef(void)
	?LogDataIn@CImMobilityLogger@@QAEXHABVTDesC8@@@Z @ 8 NONAME ; void CImMobilityLogger::LogDataIn(int, class TDesC8 const &)
	?LogDataOut@CImMobilityLogger@@QAEXHABVTDesC8@@@Z @ 9 NONAME ; void CImMobilityLogger::LogDataOut(int, class TDesC8 const &)
	?LogFormat@CImMobilityLogger@@QAAXHPBDZZ @ 10 NONAME ; void CImMobilityLogger::LogFormat(int, char const *, ...)
	?LogFormat@CImMobilityLogger@@QAAXHV?$TRefByValue@$$CBVTDesC8@@@@ZZ @ 11 NONAME ; void CImMobilityLogger::LogFormat(int, class TRefByValue<class TDesC8 const >, ...)
	?LogOn@CImMobilityLogger@@QAEXHH@Z @ 12 NONAME ; void CImMobilityLogger::LogOn(int, int)
	?LogText@CImMobilityLogger@@QAEXHABVTDesC8@@@Z @ 13 NONAME ; void CImMobilityLogger::LogText(int, class TDesC8 const &)
	?LogText@CImMobilityLogger@@QAEXHPBD@Z @ 14 NONAME ; void CImMobilityLogger::LogText(int, char const *)
	?Logger@CImMobilityPolicyProvider@@QAEAAVCImMobilityLogger@@XZ @ 15 NONAME ; class CImMobilityLogger & CImMobilityPolicyProvider::Logger(void)
	?MigrationComplete@CImMobilityPolicyProvider@@QAEXJW4TImMigrateComplete@@VTAccessPointInfo@@@Z @ 16 NONAME ; void CImMobilityPolicyProvider::MigrationComplete(long, enum TImMigrateComplete, class TAccessPointInfo)
	?PreferredCarrierAvailable@CImMobilityPolicyProvider@@QAEXAAVMImMobilityPolicyHandler@@JVTUid@@ABVTDesC8@@VTAccessPointInfo@@3HH@Z @ 17 NONAME ; void CImMobilityPolicyProvider::PreferredCarrierAvailable(class MImMobilityPolicyHandler &, long, class TUid, class TDesC8 const &, class TAccessPointInfo, class TAccessPointInfo, int, int)

